
Test doc
========

.. terminal::
    :copy:
    :scroll:
    :user: author
    :host: canonical
    :dir: ~/path
    :input: echo 'hello'

    hello
    :input: echo 'goodbye'

    goodbye

.. toctree::
    :hidden:

    myst-source
